pub struct Timestamp(/* private fields */);
UTC Timestamp with nanosecond precision, millisecond-precision when serialized to serde (JSON).

A Deref/DerefMut implementation is provided to gain access to the inner PrimitiveDateTime object.

Implementations

source

impl Timestamp

source

pub fn to_calendar_date(&self) -> (i32, Month, u8)

Get the year, month, and day.

Like PrimitiveDateTime::to_calendar_date, but optimized for SSE2/AVX2 when available.

assert_eq!(
    Timestamp::from(datetime!(2019-01-01 0:00)).to_calendar_date(),
    (2019, Month::January, 1)
);
source

impl Timestamp

source

pub fn now_utc() -> Self

Get the current time, assuming UTC

source

impl Timestamp

source

pub const UNIX_EPOCH: Self = _

Unix Epoch – 1970-01-01 Midnight

source

pub const fn from_primitive_datetime(dt: PrimitiveDateTime) -> Self

Constructs a Timestamp from a PrimitiveDateTime

source

pub fn from_unix_timestamp(seconds: i64) -> Self

👎Deprecated: Use Timestamp::UNIX_EPOCH.checked_add(Duration::seconds(seconds))
Deprecated

Use Timestamp::UNIX_EPOCH.checked_add(Duration::seconds(seconds))

source

pub fn from_unix_timestamp_ms(milliseconds: i64) -> Self

👎Deprecated: Use Timestamp::UNIX_EPOCH.checked_add(Duration::milliseconds(milliseconds))
Deprecated

Use Timestamp::UNIX_EPOCH.checked_add(Duration::milliseconds(milliseconds))

source

pub fn to_unix_timestamp_ms(self) -> i64

👎Deprecated: Use self.duration_since(Timestamp::UNIX_EPOCH).whole_milliseconds()
Deprecated

Use self.duration_since(Timestamp::UNIX_EPOCH).whole_milliseconds()

source

pub fn duration_since(self, earlier: Self) -> Duration

Returns the amount of time elapsed from an earlier point in time.

source

pub fn format_raw<F: Bit, O: Bit, P: Unsigned>( &self, offset: UtcOffset ) -> TimestampStr<FormatString<F, O, P>>
where FormatString<F, O, P>: IsValidFormat,

Formats the timestamp given the provided formatting parameters

source

pub fn format_with_precision<P: Unsigned>( &self ) -> TimestampStr<FormatString<True, False, P>>
where FormatString<True, False, P>: IsValidFormat,

Formats a full timestamp without offset, using the given subsecond precision level.

source

pub fn format(&self) -> TimestampStr<FullMilliseconds>

Format timestamp to ISO8601 with full punctuation, to millisecond precision.

source

pub fn format_nanoseconds(&self) -> TimestampStr<FullNanoseconds>

Format timestamp to ISO8601 with extended precision to nanoseconds.

source

pub fn format_microseconds(&self) -> TimestampStr<FullMicroseconds>

Format timestamp to ISO8601 with extended precision to microseconds.

source

pub fn format_short(&self) -> TimestampStr<ShortMilliseconds>

Format timestamp to ISO8601 without most punctuation, to millisecond precision.

source

pub fn format_with_offset( &self, offset: UtcOffset ) -> TimestampStr<FullMillisecondsOffset>

Format timestamp to ISO8601 with arbitrary UTC offset. Any offset is formatted as +HH:MM, and no timezone conversions are done. It is interpreted literally.

source

pub fn format_with_offset_and_precision<P: Unsigned>( &self, offset: UtcOffset ) -> TimestampStr<FormatString<True, True, P>>
where FormatString<True, True, P>: IsValidFormat,

Formats a full timestamp with timezone offset, and the provided level of subsecond precision.

source

pub fn parse(ts: &str) -> Option<Self>

Parse to UTC timestamp from any ISO8601 string. Offsets are applied during parsing.

source

pub const fn assume_offset(self, offset: UtcOffset) -> OffsetDateTime

Convert to time::OffsetDateTime with the given offset.

source

pub const fn checked_add(self, duration: Duration) -> Option<Self>

Computes self + duration, returning None if an overflow occurred.

See PrimitiveDateTime::checked_add for more implementation details

source

pub const fn checked_sub(self, duration: Duration) -> Option<Self>

Computes self - duration, returning None if an overflow occurred.

See PrimitiveDateTime::checked_sub for more implementation details

source

pub const fn saturating_add(self, duration: Duration) -> Self

Computes self + duration, saturating value on overflow.

See PrimitiveDateTime::saturating_add for more implementation details

source

pub const fn saturating_sub(self, duration: Duration) -> Self

Computes self - duration, saturating value on overflow.

See PrimitiveDateTime::saturating_sub for more implementation details

Methods from Deref<Target = PrimitiveDateTime>